@@ -308,6 +308,17 @@ def given_a_chart_of_type_chart_type(context, chart_type):
     context.chart = prs.slides[slide_idx].shapes[shape_idx].chart
 
 
+@given('a data label {having_or_not} custom font')
+def given_a_data_label_having_or_not_custom_font(context, having_or_not):
+    point_idx = {
+        'having a':  0,
+        'having no': 1,
+    }[having_or_not]
+    prs = Presentation(test_pptx('cht-point-props'))
+    points = prs.slides[2].shapes[0].chart.plots[0].series[0].points
+    context.data_label = points[point_idx].data_label
+
+
 @given('a data label {having_or_not} custom text')
 def given_a_data_label_having_or_not_custom_text(context, having_or_not):
     point_idx = {
@@ -485,6 +496,16 @@ def given_an_axis(context):
     context.axis = chart.value_axis
 
 
+@given('an axis having {a_or_no} title')
+def given_an_axis_having_a_or_no_title(context, a_or_no):
+    prs = Presentation(test_pptx('cht-axis-props'))
+    chart = prs.slides[7].shapes[0].chart
+    context.axis = {
+        'a':  chart.value_axis,
+        'no': chart.category_axis,
+    }[a_or_no]
+
+
 @given('an axis having {major_or_minor} gridlines')
 def given_an_axis_having_major_or_minor_gridlines(context, major_or_minor):
     prs = Presentation(test_pptx('cht-axis-props'))
@@ -519,6 +540,23 @@ def given_an_axis_not_having_major_or_minor_gridlines(context, major_or_minor):
     context.axis = chart.category_axis
 
 
+@given('an axis title')
+def given_an_axis_title(context):
+    prs = Presentation(test_pptx('cht-axis-props'))
+    context.axis_title = prs.slides[7].shapes[0].chart.value_axis.axis_title
+
+
+@given('an axis title having {a_or_no} text frame')
+def given_an_axis_title_having_a_or_no_text_frame(context, a_or_no):
+    prs = Presentation(test_pptx('cht-axis-props'))
+    chart = prs.slides[7].shapes[0].chart
+    axis = {
+        'a':  chart.value_axis,
+        'no': chart.category_axis,
+    }[a_or_no]
+    context.axis_title = axis.axis_title
+
+
 @given('a XyChartData object with number format {strval}')
 def given_a_XyChartData_object_with_number_format(context, strval):
     params = {}
@@ -705,6 +743,11 @@ def when_I_add_an_xy_chart_having_2_series_of_3_points(context, xy_type):
     ).chart
 
 
+@when('I assign {value} to axis.has_title')
+def when_I_assign_value_to_axis_has_title(context, value):
+    context.axis.has_title = {'True': True, 'False': False}[value]
+
+
 @when('I assign {value} to axis.has_{major_or_minor}_gridlines')
 def when_I_assign_value_to_axis_has_major_or_minor_gridlines(
         context, value, major_or_minor):
@@ -723,6 +766,11 @@ def when_I_assign_value_to_axis_major_or_minor_unit(
     setattr(axis, propname, new_value)
 
 
+@when('I assign {value} to axis_title.has_text_frame')
+def when_I_assign_value_to_axis_title_has_text_frame(context, value):
+    context.axis_title.has_text_frame = {'True': True, 'False': False}[value]
+
+
 @when('I assign {value} to bubble_plot.bubble_scale')
 def when_I_assign_value_to_bubble_plot_bubble_scale(context, value):
     new_value = None if value == 'None' else int(value)
@@ -907,6 +955,12 @@ def then_c_label_for_c_in_chart_data_categories_is_a_b_c(context):
     assert [c.label for c in chart_data.categories] == ['a', 'b', 'c']
 
 
+@then('axis.axis_title is an AxisTitle object')
+def then_axis_axis_title_is_an_AxisTitle_object(context):
+    class_name = type(context.axis.axis_title).__name__
+    assert class_name == 'AxisTitle', 'got %s' % class_name
+
+
 @then('axis.category_type is XL_CATEGORY_TYPE.{member}')
 def then_axis_category_type_is_XL_CATEGORY_TYPE_member(context, member):
     expected_value = getattr(XL_CATEGORY_TYPE, member)
@@ -932,6 +986,14 @@ def then_axis_format_line_is_a_LineFormat_object(context):
     assert type(axis.format.line).__name__ == 'LineFormat'
 
 
+@then('axis.has_title is {value}')
+def then_axis_has_title_is_value(context, value):
+    axis = context.axis
+    actual_value = axis.has_title
+    expected_value = {'True': True, 'False': False}[value]
+    assert actual_value is expected_value, 'got %s' % actual_value
+
+
 @then('axis.has_{major_or_minor}_gridlines is {value}')
 def then_axis_has_major_or_minor_gridlines_is_expected_value(
         context, major_or_minor, value):
@@ -961,6 +1023,37 @@ def then_axis_major_or_minor_unit_is_value(context, major_or_minor, value):
     assert actual_value == expected_value, 'got %s' % actual_value
 
 
+@then('axis_title.format is a ChartFormat object')
+def then_axis_title_format_is_a_ChartFormat_object(context):
+    class_name = type(context.axis_title.format).__name__
+    assert class_name == 'ChartFormat', 'got %s' % class_name
+
+
+@then('axis_title.format.fill is a FillFormat object')
+def then_axis_title_format_fill_is_a_FillFormat_object(context):
+    class_name = type(context.axis_title.format.fill).__name__
+    assert class_name == 'FillFormat', 'got %s' % class_name
+
+
+@then('axis_title.format.line is a LineFormat object')
+def then_axis_title_format_line_is_a_LineFormat_object(context):
+    class_name = type(context.axis_title.format.line).__name__
+    assert class_name == 'LineFormat', 'got %s' % class_name
+
+
+@then('axis_title.has_text_frame is {value}')
+def then_axis_title_has_text_frame_is_value(context, value):
+    actual_value = context.axis_title.has_text_frame
+    expected_value = {'True': True, 'False': False}[value]
+    assert actual_value is expected_value, 'got %s' % actual_value
+
+
+@then('axis_title.text_frame is a TextFrame object')
+def then_axis_title_text_frame_is_a_TextFrame_object(context):
+    class_name = type(context.axis_title.text_frame).__name__
+    assert class_name == 'TextFrame', 'got %s' % class_name
+
+
 @then('bubble_plot.bubble_scale is {value}')
 def then_bubble_plot_bubble_scale_is_value(context, value):
     expected_value = int(value)
@@ -1126,6 +1219,12 @@ def then_chart_data_minus_1_is_the_new_series(context):
     assert chart_data[-1] is series
 
 
+@then('data_label.font is a Font object')
+def then_data_label_font_is_a_Font_object(context):
+    font = context.data_label.font
+    assert type(font).__name__ == 'Font'
+
+
 @then('data_label.has_text_frame is {value}')
 def then_data_label_has_text_frame_is_value(context, value):
     expected_value = {'True': True, 'False': False}[value]
