@@ -11,6 +11,7 @@ from behave import given, when, then
 from pptx import Presentation
 from pptx.chart.chart import Chart
 from pptx.dml.color import RGBColor
+from pptx.enum.chart import XL_CHART_TYPE
 from pptx.enum.dml import MSO_FILL, MSO_THEME_COLOR
 from pptx.enum.shapes import MSO_CONNECTOR, MSO_SHAPE, MSO_SHAPE_TYPE
 from pptx.action import ActionSetting
@@ -21,13 +22,6 @@ from helpers import cls_qname, saved_pptx_path, test_pptx, test_text
 
 # given ===================================================
 
-@given('a chart')
-def given_a_chart(context):
-    prs = Presentation(test_pptx('shp-common-props'))
-    sld = prs.slides[0]
-    context.shape = sld.shapes[6]
-
-
 @given('a chevron shape')
 def given_a_chevron_shape(context):
     prs = Presentation(test_pptx('shp-autoshape-adjustments'))
@@ -137,13 +131,6 @@ def given_a_SlideShapes_obj_having_type_shape_at_off_idx(context, type, idx):
     context.shapes = prs.slides[1].shapes
 
 
-@given('a table')
-def given_a_table(context):
-    prs = Presentation(test_pptx('shp-common-props'))
-    sld = prs.slides[0]
-    context.shape = sld.shapes[2]
-
-
 @given('a textbox')
 def given_a_textbox(context):
     prs = Presentation(test_pptx('shp-common-props'))
@@ -256,6 +243,14 @@ def when_I_call_connector_end_connect_picture_3(context):
     connector.end_connect(picture, 3)
 
 
+@when('I call shapes.add_chart({type_}, chart_data)')
+def when_I_call_shapes_add_chart(context, type_):
+    chart_type = getattr(XL_CHART_TYPE, type_)
+    context.chart = context.shapes.add_chart(
+        chart_type, 0, 0, 0, 0, context.chart_data
+    ).chart
+
+
 @when('I call shapes.add_connector(MSO_CONNECTOR.STRAIGHT, 1, 2, 3, 4)')
 def when_I_call_shapes_add_connector(context):
     context.connector = context.shapes.add_connector(
